==> glue-1.93.0-sources.jar: software/amazon/awscdk/services/glue/CfnDatabaseProps.java <==
package software.amazon.awscdk.services.glue;

/**
 * Properties for defining a `AWS::Glue::Database`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.454Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.CfnDatabaseProps")
@software.amazon.jsii.Jsii.Proxy(CfnDatabaseProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnDatabaseProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Glue::Database.CatalogId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getCatalogId();

    /**
     * `AWS::Glue::Database.DatabaseInput`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getDatabaseInput();

    /**
     * @return a {@link Builder} of {@link CfnDatabaseProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnDatabaseProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnDatabaseProps> {
        private java.lang.String catalogId;
        private java.lang.Object databaseInput;

        /**
         * Sets the value of {@link CfnDatabaseProps#getCatalogId}
         * @param catalogId `AWS::Glue::Database.CatalogId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder catalogId(java.lang.String catalogId) {
            this.catalogId = catalogId;
            return this;
        }

        /**
         * Sets the value of {@link CfnDatabaseProps#getDatabaseInput}
         * @param databaseInput `AWS::Glue::Database.DatabaseInput`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder databaseInput(software.amazon.awscdk.core.IResolvable databaseInput) {
            this.databaseInput = databaseInput;
            return this;
        }

        /**
         * Sets the value of {@link CfnDatabaseProps#getDatabaseInput}
         * @param databaseInput `AWS::Glue::Database.DatabaseInput`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder databaseInput(software.amazon.awscdk.services.glue.CfnDatabase.DatabaseInputProperty databaseInput) {
            this.databaseInput = databaseInput;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnDatabaseProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnDatabaseProps build() {
            return new Jsii$Proxy(catalogId, databaseInput);
        }
    }

    /**
     * An implementation for {@link CfnDatabaseProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnDatabaseProps {
        private final java.lang.String catalogId;
        private final java.lang.Object databaseInput;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.catalogId = software.amazon.jsii.Kernel.get(this, "catalogId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.databaseInput = software.amazon.jsii.Kernel.get(this, "databaseInput", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String catalogId, final java.lang.Object databaseInput) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.catalogId = java.util.Objects.requireNonNull(catalogId, "catalogId is required");
            this.databaseInput = java.util.Objects.requireNonNull(databaseInput, "databaseInput is required");
        }

        @Override
        public final java.lang.String getCatalogId() {
            return this.catalogId;
        }

        @Override
        public final java.lang.Object getDatabaseInput() {
            return this.databaseInput;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("catalogId", om.valueToTree(this.getCatalogId()));
            data.set("databaseInput", om.valueToTree(this.getDatabaseInput()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-glue.CfnDatabaseProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnDatabaseProps.Jsii$Proxy that = (CfnDatabaseProps.Jsii$Proxy) o;

            if (!catalogId.equals(that.catalogId)) return false;
            return this.databaseInput.equals(that.databaseInput);
        }

        @Override
        public final int hashCode() {
            int result = this.catalogId.hashCode();
            result = 31 * result + (this.databaseInput.hashCode());
            return result;
        }
    }
}

==> glue-1.182.0-sources.jar: software/amazon/awscdk/services/glue/CfnDatabaseProps.java <==
package software.amazon.awscdk.services.glue;

/**
 * Properties for defining a `CfnDatabase`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.glue.*;
 * Object parameters;
 * CfnDatabaseProps cfnDatabaseProps = CfnDatabaseProps.builder()
 *         .catalogId("catalogId")
 *         .databaseInput(DatabaseInputProperty.builder()
 *                 .createTableDefaultPermissions(List.of(PrincipalPrivilegesProperty.builder()
 *                         .permissions(List.of("permissions"))
 *                         .principal(DataLakePrincipalProperty.builder()
 *                                 .dataLakePrincipalIdentifier("dataLakePrincipalIdentifier")
 *                                 .build())
 *                         .build()))
 *                 .description("description")
 *                 .locationUri("locationUri")
 *                 .name("name")
 *                 .parameters(parameters)
 *                 .targetDatabase(DatabaseIdentifierProperty.builder()
 *                         .catalogId("catalogId")
 *                         .databaseName("databaseName")
 *                         .build())
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:43.319Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.CfnDatabaseProps")
@software.amazon.jsii.Jsii.Proxy(CfnDatabaseProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnDatabaseProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The AWS account ID for the account in which to create the catalog object.
     * <p>
     * <blockquote>
     * <p>
     * To specify the account ID, you can use the <code>Ref</code> intrinsic function with the <code>AWS::AccountId</code> pseudo parameter. For example: <code>!Ref AWS::AccountId</code>
     * <p>
     * </blockquote>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getCatalogId();

    /**
     * The metadata for the database.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getDatabaseInput();

    /**
     * @return a {@link Builder} of {@link CfnDatabaseProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnDatabaseProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnDatabaseProps> {
        java.lang.String catalogId;
        java.lang.Object databaseInput;

        /**
         * Sets the value of {@link CfnDatabaseProps#getCatalogId}
         * @param catalogId The AWS account ID for the account in which to create the catalog object. This parameter is required.
         *                  <blockquote>
         *                  <p>
         *                  To specify the account ID, you can use the <code>Ref</code> intrinsic function with the <code>AWS::AccountId</code> pseudo parameter. For example: <code>!Ref AWS::AccountId</code>
         *                  <p>
         *                  </blockquote>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder catalogId(java.lang.String catalogId) {
            this.catalogId = catalogId;
            return this;
        }

        /**
         * Sets the value of {@link CfnDatabaseProps#getDatabaseInput}
         * @param databaseInput The metadata for the database. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder databaseInput(software.amazon.awscdk.core.IResolvable databaseInput) {
            this.databaseInput = databaseInput;
            return this;
        }

        /**
         * Sets the value of {@link CfnDatabaseProps#getDatabaseInput}
         * @param databaseInput The metadata for the database. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder databaseInput(software.amazon.awscdk.services.glue.CfnDatabase.DatabaseInputProperty databaseInput) {
            this.databaseInput = databaseInput;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnDatabaseProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnDatabaseProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnDatabaseProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnDatabaseProps {
        private final java.lang.String catalogId;
        private final java.lang.Object databaseInput;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.catalogId = software.amazon.jsii.Kernel.get(this, "catalogId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.databaseInput = software.amazon.jsii.Kernel.get(this, "databaseInput", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.catalogId = java.util.Objects.requireNonNull(builder.catalogId, "catalogId is required");
            this.databaseInput = java.util.Objects.requireNonNull(builder.databaseInput, "databaseInput is required");
        }

        @Override
        public final java.lang.String getCatalogId() {
            return this.catalogId;
        }

        @Override
        public final java.lang.Object getDatabaseInput() {
            return this.databaseInput;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("catalogId", om.valueToTree(this.getCatalogId()));
            data.set("databaseInput", om.valueToTree(this.getDatabaseInput()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-glue.CfnDatabaseProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnDatabaseProps.Jsii$Proxy that = (CfnDatabaseProps.Jsii$Proxy) o;

            if (!catalogId.equals(that.catalogId)) return false;
            return this.databaseInput.equals(that.databaseInput);
        }

        @Override
        public final int hashCode() {
            int result = this.catalogId.hashCode();
            result = 31 * result + (this.databaseInput.hashCode());
            return result;
        }
    }
}
